Implemented functions
=====================

In the following we list the elementary functions currently implemented in the code.

These functions are characterized by the fact that their derivatives are known and can
be easily computed up to any order.

.. automodule:: njet.functions
    :members:
    :undoc-members:
    :exclude-members: get_function, detect_code, jetfunc

